<?php
/* Displays an invite RSVP and allows a visitor to update their reply */
require (__DIR__ . '/vendor/autoload.php');

ini_set('display_errors', 1);
$dbh = new PDO('sqlite:../invites.db');

$event_id = $_GET['event'] ?? null;

if (empty($event_id)) {
    trigger_error("Invite ID missing", E_USER_ERROR);
}

// fetch the invite as an arrow from the database
$stmt = $dbh->prepare("SELECT * FROM events WHERE uid=?");
if ($result = $stmt->execute([$event_id])) {
    $row = $stmt->fetch(PDO::FETCH_ASSOC);
    switch ($row['event_type']) {
        case 'all_day':
            $event = new \Phparch\Events\AllDay(
                $row['id'], $row['title'],
                $row['event_date'], $row['event_type'], $row['uid']
            );
        case 'timed':
            $event = new \Phparch\Events\Timed(
                $row['id'], $row['title'],
                $row['event_date'], $row['event_type'], $row['uid']
            );
    }
}

if (!empty($_POST)) {
    $stmt = $dbh->prepare("REPLACE INTO replies (event_id, email, reply, updated) VALUES (?, ?, ?, ?)");
    $now = new \DateTime();
    $result = $stmt->execute([
        $event->getId(),
        filter_var($_POST['email'], FILTER_SANITIZE_EMAIL),
        $_POST['response'],
        $now->format('Y-m-d H:i:s'),
    ]);

    $msg = "Your response was saved";
}

// display form
?>
<html>
<body>
<h2><?= htmlentities($event->getTitle()) ?></h2>
<p><?= $event->getDescription() ?></p>
<?php if (isset($msg)): ?>
    <p><?php echo $msg ?></p>
<?php endif; ?>

<form method="POST" action="">
    <label>Your Email <input type="email" name="email" value="" required="required"/></label>
    <p><b>Will You Attend?</b></p>
    <div>
    <label><input type="radio" name="response" value="yes">Yes</label>
    <label><input type="radio" name="response" value="no">No</label>
    <label><input type="radio" name="response" value="maybe">Maybe</label>
    </div>
    <input type="submit" name="submit"value="Save Your Reply" />
</form>
</body>

</html>
